@@ -26,7 +26,7 @@
 ##  shiela.pl: control program (syntax: Perl)
 ##
 
-my $version = '1.0.1';
+my $version = '1.0.2';
 
 require 5.005;
 
@@ -167,7 +167,7 @@ sub rt_determine_two {
     sub find_program {
         my ($name) = @_;
         my ($prog) = '';
-        foreach my $dir (split(/:/, "$ENV{PATH}:/usr/local/lib:/usr/lib:/lib")) {
+        foreach my $dir (split(/:/, "$ENV{PATH}:/bin:/usr/bin:/sbin:/usr/sbin")) {
             if (-x "$dir/$name") {
                 $prog = "$dir/$name";
                 last;
@@ -1699,7 +1699,8 @@ sub hook_loginfo_collect {
                 if ($RT->{xdelta} and $RT->{uuencode}) {
                     $cvsdiff .=
                         "<shiela:patch $cvsdir/$Is>\n" .
-                        "(cd $cvsdir && uudecode <<'@@ .' && \\\n" .
+                        "(cd $cvsdir && \\\n" .
+                        " uudecode <<'@@ .' && \\\n" .
                         " xdelta patch $Is.xdelta /dev/null $Is && \\\n" .
                         " rm -f $Is.xdelta)\n" .
                         "Index: $cvsdir/$Is\n" .
@@ -1711,7 +1712,7 @@ sub hook_loginfo_collect {
                     $io->close;
                     system("$RT->{xdelta} delta $RT->{tmpfile}.null " .
                            "$RT->{tmpfile}.all $RT->{tmpfile}.xdelta >/dev/null 2>&1");
-                    $io = new IO::File "uuencode $RT->{tmpfile}.xdelta $Is.xdelta |"
+                    $io = new IO::File "$RT->{uuencode} $RT->{tmpfile}.xdelta $Is.xdelta |"
                         || die "unable to open uuencode command pipe for reading";
                     $cvsdiff .= $_ while (<$io>);
                     $io->close;
@@ -1800,15 +1801,17 @@ sub hook_loginfo_collect {
                     #   generate change patch script
                     $cvsdiff .=
                         "<shiela:patch $cvsdir/$Is>\n" .
-                        "(cd $cvsdir && uudecode <<'@@ .' && \\\n" .
-                        " mv $Is $Is.orig && xdelta patch $Is.xdelta $Is.orig $Is && \\\n" .
+                        "(cd $cvsdir && \\\n" .
+                        " uudecode <<'@@ .' && \\\n" .
+                        " mv $Is $Is.orig && \\\n" .
+                        " xdelta patch $Is.xdelta $Is.orig $Is && \\\n" .
                         " rm -f $Is.orig $Is.xdelta)\n" .
                         "Index: $cvsdir/$Is\n" .
                         ("=" x 76) . "\n";
                     unlink("$RT->{tmpfile}.xdelta");
                     system("$RT->{xdelta} delta $RT->{tmpfile}.old " .
                            "$RT->{tmpfile}.new $RT->{tmpfile}.xdelta >/dev/null 2>&1");
-                    $io = new IO::File "uuencode $RT->{tmpfile}.xdelta $Is.xdelta |"
+                    $io = new IO::File "$RT->{uuencode} $RT->{tmpfile}.xdelta $Is.xdelta |"
                         || die "unable to open uuencode command pipe for reading";
                     $cvsdiff .= $_ while (<$io>);
                     $io->close;
